/**
 * @jest-environment jsdom
 */

import WalletSummary from "$lib/components/accounts/WalletSummary.svelte";
import {
  SELECTED_ACCOUNT_CONTEXT_KEY,
  type SelectedAccountContext,
  type SelectedAccountStore,
} from "$lib/types/selected-account.context";
import { replacePlaceholders } from "$lib/utils/i18n.utils";
import { formatToken } from "$lib/utils/token.utils";
import { render } from "@testing-library/svelte";
import { writable } from "svelte/store";
import { mockMainAccount } from "../../../mocks/accounts.store.mock";
import en from "../../../mocks/i18n.mock";
import ContextWrapperTest from "../ContextWrapperTest.svelte";

describe("WalletSummary", () => {
  const renderWalletSummary = () =>
    render(ContextWrapperTest, {
      props: {
        contextKey: SELECTED_ACCOUNT_CONTEXT_KEY,
        contextValue: {
          store: writable<SelectedAccountStore>({
            account: mockMainAccount,
          }),
        } as SelectedAccountContext,
        Component: WalletSummary,
      },
    });

  it("should render title", () => {
    const { getByText } = renderWalletSummary();

    expect(getByText(en.accounts.main)).toBeInTheDocument();
  });

  it("should render an account identifier", () => {
    const { getByText } = renderWalletSummary();

    expect(
      getByText(mockMainAccount.identifier, { exact: false })
    ).toBeInTheDocument();
  });

  it("should render a balance in ICP", () => {
    const { getByText, queryByTestId } = renderWalletSummary();

    const icp: HTMLSpanElement | null = queryByTestId("token-value");

    expect(icp?.innerHTML).toEqual(
      `${formatToken({ value: mockMainAccount.balance.toE8s() })}`
    );
    expect(getByText(`ICP`)).toBeTruthy();
  });

  it("should contain a tooltip", () => {
    const { container } = renderWalletSummary();

    expect(container.querySelector(".tooltip-wrapper")).toBeInTheDocument();
  });

  it("should render a detailed balance in ICP in a tooltip", () => {
    const { container } = renderWalletSummary();

    const icp: HTMLDivElement | null = container.querySelector(
      "#wallet-detailed-icp"
    );

    expect(icp?.textContent).toEqual(
      replacePlaceholders(en.accounts.current_balance_detail, {
        $amount: `${formatToken({
          value: mockMainAccount.balance.toE8s(),
          detailed: true,
        })}`,
      })
    );
  });
});
